@@ -44,7 +44,7 @@ def test_check_expire():
 
 
 def test_token_to_user_id():
-    assert USER_ID == sso._token_to_user_id(TOKEN)
+    assert USER_ID == sso.token_to_user_id(TOKEN)
 
 
 def test_redis_token_operate():
